@@ -83,8 +83,8 @@ void
 ags_functional_panel_test_add_test()
 {
   /* add the tests to the suite */
-  if((CU_add_test(pSuite, "functional test of AgsPanel resize pads\0", ags_functional_panel_test_resize_pads) == NULL) ||
-     (CU_add_test(pSuite, "functional test of AgsPanel resize audio channels\0", ags_functional_panel_test_resize_audio_channels) == NULL)){
+  if((CU_add_test(pSuite, "functional test of AgsPanel resize pads", ags_functional_panel_test_resize_pads) == NULL) ||
+     (CU_add_test(pSuite, "functional test of AgsPanel resize audio channels", ags_functional_panel_test_resize_audio_channels) == NULL)){
     CU_cleanup_registry();
       
     exit(CU_get_error());
@@ -295,7 +295,7 @@ main(int argc, char **argv)
   }
 
   /* add a suite to the registry */
-  pSuite = CU_add_suite("AgsFuncitonalPanelTest\0", ags_functional_panel_test_init_suite, ags_functional_panel_test_clean_suite);
+  pSuite = CU_add_suite("AgsFunctionalPanelTest", ags_functional_panel_test_init_suite, ags_functional_panel_test_clean_suite);
   
   if(pSuite == NULL){
     CU_cleanup_registry();
